Customer class

Implementers

Constructors

Customer({String? id, String? name, required String email, required String phoneNumber, double? longtitude, double? latitude, String? language, required String uuid, String? jwtToken, List<OrderProduct>? currentOrders, List<OrderProduct>? favoriteProducts, int roleId = 0})

Properties

currentOrders List<OrderProduct>?
final
email String
final
favoriteProducts List<OrderProduct>?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
jwtToken String?
final
language String?
final
latitude double?
final
longtitude double?
final
name String?
final
phoneNumber String
final
roleId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited